<H2 style="color:orange;">laptools is currently unstable.</H2>

![Black Logo](logo.png)

<h2 align="center">Fast Assignment Problem Solvers</h2>

<p align="center">
<a href="https://pypi.org/project/laptools/"><img alt="PyPI Version" src="https://img.shields.io/pypi/v/laptools.svg"></a>
<a href="https://pypi.org/project/laptools/"><img alt="Supported Python Versions" src="https://img.shields.io/pypi/pyversions/laptools.svg"></a>
<a href="https://github.com/jdmoorman/laptools/actions"><img alt="Build Status" src="https://github.com/jdmoorman/laptools/workflows/CI/badge.svg"></a>
<a href="https://codecov.io/gh/jdmoorman/laptools"><img alt="Code Coverage" src="https://codecov.io/gh/jdmoorman/laptools/branch/master/graph/badge.svg"></a>
<a href="https://github.com/psf/black"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>
</p>

---

## Installation

To install laptools, run this command in your terminal:

```bash
$ pip install -U laptools
```

This is the preferred method to install laptools,
as it will always install the most recent release.

If you don't have [pip](https://pip.pypa.io) installed,
these [installation instructions](http://docs.python-guide.org/en/latest/starting/installation/) can guide
you through the process.

## Development
See [CONTRIBUTING.md](CONTRIBUTING.md) for information related to developing the code.
